import { hasProperPassengerSeats } from '../../../domain/dtos/validators/has-passenger-seats';

describe('driver and/or passenger seats validator', () => {
  it('should validate if passenger and passengers seats is not provided ', () => {
    expect(
      hasProperPassengerSeats({
        value: undefined,
        constraints: [],
        targetName: '',
        object: { passenger: undefined },
        property: '',
      }),
    ).toBe(true);
    expect(
      hasProperPassengerSeats({
        value: undefined,
        constraints: [],
        targetName: '',
        object: { passenger: false },
        property: '',
      }),
    ).toBe(true);
    expect(
      hasProperPassengerSeats({
        value: undefined,
        constraints: [],
        targetName: '',
        object: { passenger: null },
        property: '',
      }),
    ).toBe(true);
  });
  it('should not validate if passenger is set to true but not the related seats is not provided or 0', () => {
    expect(
      hasProperPassengerSeats({
        value: undefined,
        constraints: [],
        targetName: '',
        object: { passenger: true },
        property: '',
      }),
    ).toBe(false);
    expect(
      hasProperPassengerSeats({
        value: undefined,
        constraints: [],
        targetName: '',
        object: { passenger: true, seatsPassenger: 0 },
        property: '',
      }),
    ).toBe(false);
    expect(
      hasProperPassengerSeats({
        value: undefined,
        constraints: [],
        targetName: '',
        object: { passenger: true, seatsPassenger: undefined },
        property: '',
      }),
    ).toBe(false);
    expect(
      hasProperPassengerSeats({
        value: undefined,
        constraints: [],
        targetName: '',
        object: { passenger: true, seatsPassenger: null },
        property: '',
      }),
    ).toBe(false);
  });
  it('should not validate if passenger seats are provided but passenger is not set or set to false ', () => {
    expect(
      hasProperPassengerSeats({
        value: undefined,
        constraints: [],
        targetName: '',
        object: { passenger: false, seatsPassenger: 1 },
        property: '',
      }),
    ).toBe(false);
    expect(
      hasProperPassengerSeats({
        value: undefined,
        constraints: [],
        targetName: '',
        object: { passenger: undefined, seatsPassenger: 1 },
        property: '',
      }),
    ).toBe(false);
    expect(
      hasProperPassengerSeats({
        value: undefined,
        constraints: [],
        targetName: '',
        object: { passenger: null, seatsPassenger: 1 },
        property: '',
      }),
    ).toBe(false);
  });
});
