import { isPunctualOrRecurrent } from '../../../domain/dtos/validators/is-punctual-or-recurrent';
import { Frequency } from '../../../domain/types/frequency.enum';

describe('punctual or reccurent validators', () => {
  describe('punctual case ', () => {
    describe('valid cases', () => {
      it('should validate with valid departure and empty schedule ', () => {
        expect(
          isPunctualOrRecurrent({
            value: undefined,
            constraints: [],
            targetName: '',
            object: {
              frequency: Frequency.PUNCTUAL,
              departure: new Date('01-02-2023'),
              schedule: {},
            },
            property: '',
          }),
        ).toBeTruthy();
      });
    });
    describe('invalid cases ', () => {
      it('should not validate with invalid departure and empty schedule and margin', () => {
        expect(
          isPunctualOrRecurrent({
            value: undefined,
            constraints: [],
            targetName: '',
            object: {
              frequency: Frequency.PUNCTUAL,
              fromDate: new Date('20-10-2023'),
              toDate: new Date('30-10-2023'),
            },
            property: '',
          }),
        ).toBeFalsy();
      });
      it('should not validate with no empty schedule', () => {
        expect(
          isPunctualOrRecurrent({
            value: undefined,
            constraints: [],
            targetName: '',
            object: {
              frequency: Frequency.PUNCTUAL,
              departure: new Date('01-02-2023'),
              schedule: {
                mon: '08:30',
              },
            },
            property: '',
          }),
        ).toBeFalsy();
      });
    });
  });
  describe('reccurent case ', () => {
    describe('valid cases', () => {
      it('should validate with valid from date, to date and non empty schedule  ', () => {
        expect(
          isPunctualOrRecurrent({
            value: undefined,
            constraints: [],
            targetName: '',
            object: {
              frequency: Frequency.RECURRENT,
              fromDate: new Date('01-15-2023'),
              toDate: new Date('06-30-2023'),
              schedule: {
                mon: '08:30',
              },
            },
            property: '',
          }),
        ).toBeTruthy();
      });
    });
    describe('invalid cases ', () => {
      it('should not validate with  empty schedule  ', () => {
        expect(
          isPunctualOrRecurrent({
            value: undefined,
            constraints: [],
            targetName: '',
            object: {
              frequency: Frequency.RECURRENT,
              fromDate: new Date('01-15-2023'),
              toDate: new Date('06-30-2023'),
              schedule: {},
            },
            property: '',
          }),
        ).toBeFalsy();
      });
      it('should not validate with invalid from date to date and empty schedule and margin', () => {
        expect(
          isPunctualOrRecurrent({
            value: undefined,
            constraints: [],
            targetName: '',
            object: {
              frequency: Frequency.RECURRENT,
              departure: new Date('20-10-2023'),
              toDate: new Date('30-10-2023'),
            },
            property: '',
          }),
        ).toBeFalsy();
      });
    });
  });
});
